(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 4.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     33997,        732]*)
(*NotebookOutlinePosition[     34755,        757]*)
(*  CellTagsIndexPosition[     34711,        753]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["\<\
Notebook to perform analyses in Piganeau and Eyre-Walker (2003) \
PNAS\
\>", "Title"],

Cell[TextData[{
  "Instructions\nThe routines below allow you to estimate the parameters of a \
gamma or partially reflected gamma distribution of fitness effects using the \
method of Piganeau and Eyre-Walker (2003) PNAS. The techniques used here are \
not particularly sophisticated so it can take some work to find the ML \
values. You should run the \"Basic statistical routines\" and \"Analysis \
routines\". You should also run \"Routines for the gamma distribution\" or \
\"Routines for the partially reflected gamma distribution\" depending upon \
which distribution you wish to investigate.\n\nData needs to be in the form \
of a list which is as follows {no of alleles, length of sequence, proportion \
of sites which are non-synonymous, Dn, Ds, Pn, Ps}\n\nTo find the ML values \
of the distributions you need to run FindML or FindMLlog. These won't always \
work because the algorithm does not place bounds on the parameters so they \
can become negative. If you have alot of problems then use the Manual \
function which allows you to search the parameter space manually - its easier \
than you think. Once you find parameter values which get you fairly close to \
the observed values you can then use FindML and FindMLlog. The differences \
between these two functions is the scale they search for the ML value of \
meanS over; FindMLlog often outperfoms FindML, and is generally the \
recommended function to use. Both routines are run using the command \
FindML[data,meanSStart,\[Beta]Start] or \
FindMLlog[data,meanSStart,\[Beta]Start], where meanSStart and \[Beta]Start \
are the starting values for the parameters of the gamma distribution. The \
gamma distribution is parameterised in terms of the mean strength of \
selection, meanS (this is the mean of 4Ns for diploids or 2Ns for haploids), \
and the shape parameter, \[Beta]. \n\nI have provided two routines to find \
the confidence intervals of the meanS and \[Beta] parameters, these are \
respectively CImeanS and CI\[Beta]. Unfortunately these are not very \
sophisticated at the moment; they simply allow one to work out the likelihood \
surface for meanS and \[Beta], from which you can infer the CIs. In short \
they find the ML estimates of all other parameters given a fixed value of \
meanS and \[Beta] respectively along with the likelihood value. To find the \
CI values of \[Beta] you run CI\[Beta][data,meanSStart,\[Beta]] for different \
values of \[Beta] until you find the value which 2 log likelihood values \
below the ML value of the likelihood. The CIs so obtained assume free \
recombination.\n\nNote that the method assumes that Pn/Ps > Dn/Ds. If this \
condition is not met you will not get a sensible solution.\n\nI have included \
a test dataset below so that you can check that everything works fine. \
Unfortunately ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " 5.1 seems to produce integration error messages, but never-the-less finds \
the correct answer.\n\nData supplied as {no of chromosomes, sequence length, \
proportion of mutations that are non-synonymous, Dn, Ds, Pn, Ps}\n\nIf you \
have any problems please contact Adam Eyre-Walker \
(a.c.eyre-walker@sussex.ac.uk)\n\n"
}], "Section",
  CellChangeTimes -> {{3.528624654811764*^9, 3.528624693251688*^9}}],

Cell[CellGroupData[{

Cell["Basic statistical routines", "Section"],

Cell[BoxData[{
    \(Needs["\<Statistics`DataManipulation`\>"]\), "\n", 
    \(Needs["\<Graphics`Graphics`\>"]\), "\n", 
    \(Needs["\<Statistics`ContinuousDistributions`\>"]\)}], "Input",
  PageWidth->Infinity,
  CellChangeTimes -> {3.52862449153022*^9}],

Cell[BoxData[{
    \(Poisson[m_, x_] := 
      E^\((\(-m\))\) m^x/\(x!\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(Gtest[obs_, exp_] := \n\t
      Module[{Gt, Gtsum, ob, 
          ex}, \n\t\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ ob = 
          Flatten[obs]; \n\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ ex = 
          Flatten[exp]; \n\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ Gt = 2*ob*Log[ob/ex]; \n\t\t\ \ \ \ \ \ \ \ \ Gtsum = 
          Apply[Plus, Gt]; \n\t\t\ \ \ \ \ \ \ \ \ {Gt, Gtsum}]\n\), "\n", 
    \(\)}], "Input",
  PageWidth->Infinity,
  CellChangeTimes -> {3.52862449153022*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Routines for the gamma distribution", "Section"],

Cell[BoxData[{
    \(gamma[\[Alpha]_, \[Beta]_, 
        S_] := \[Alpha]^\[Beta]\ S^\((\[Beta] - 
              1)\)\ E^\((\(-\[Alpha]\)\ S)\)/
          Gamma[\[Beta]]\[IndentingNewLine]\), "\n", 
    \(P[S_] := S/\((1 - E^\((\(-S\))\))\)\[IndentingNewLine]\), "\n", 
    \(EPs[l_, n_, \[Rho]_, \[Theta]_] := 
      l*\((1 - \[Rho])\)*\[Theta]*Apply[Plus, Table[1/i, {i, 1, n - 1}]]\  // 
        N\n\), "\n", 
    \(Q[n_, x_] := 1 - x^n - \((1 - x)\)^n\n\), "\[IndentingNewLine]", 
    \(EPn[l_, 
        n_, \[Rho]_, \[Theta]_, \[Alpha]_, \[Beta]_] := \[IndentingNewLine]\ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ l*\[Rho]*\[Theta]*\((NIntegrate[\
\[Alpha]^\[Beta]\ \((Zeta[\[Beta], \[Alpha]\  + x] - 
                  Zeta[\[Beta], \[Alpha]\  + \ 1])\)\ Q[n, 
                  x]/\((x \((1 - x)\))\), {x, 0, 
              1}]\ )\)\n\), "\[IndentingNewLine]", 
    \(EDs[l_, \[Rho]_, \[Lambda]_] := 
      l*\((1 - \[Rho])\)*\[Lambda]\n\), "\[IndentingNewLine]", 
    \(EDn[
        l_, \[Rho]_, \[Lambda]_, \[Alpha]_, \[Beta]_] := \[IndentingNewLine]\ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ l*\[Rho]*\[Lambda]*\((\((\[Beta]\ \
\[Alpha]^\[Beta]\ \ Zeta[1 + \[Beta], 1 + \[Alpha]])\))\)\), "\n", 
    \(\t\)}], "Input",
  PageWidth->Infinity]
}, Open  ]],

Cell[CellGroupData[{

Cell["Routines for the partially reflected gamma", "Section"],

Cell[BoxData[
    \(\(\(\[IndentingNewLine]\)\(\(gamma[\[Alpha]_, \[Beta]_, 
          S_] := \[Alpha]^\[Beta]\ S^\((\[Beta] - 
                1)\)\ E^\((\(-\[Alpha]\)\ S)\)/
            Gamma[\[Beta]]\)\[IndentingNewLine]\[IndentingNewLine]\(F[S_] := 
        E^S/\((E^S + 1)\)\)\[IndentingNewLine]\n\(P[S_] := 
        S/\((1 - 
              E^\((\(-S\))\))\)\)\[IndentingNewLine]\n\
\[IndentingNewLine]\(EPs[l_, n_, \[Rho]_, \[Theta]_] := 
        l*\((1 - \[Rho])\)*\[Theta]*Apply[Plus, Table[1/i, {i, 1, n - 1}]]\  // 
          N\)\n\n\(EPn[k_, l_, 
          n_, \[Rho]_, \[Theta]_, \[Alpha]_, \[Beta]_] := \[IndentingNewLine]\
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ l*\[Rho]*\[Theta]*\((\
GammaRegularized[\[Beta], 0, 0.001*\[Alpha]]*
                NIntegrate[\((1 - x^n - \((1 - x)\)^n)\)/x, {x, 0, 
                    1}] + \[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ NIntegrate[\((F[\(-S\)]*\((1 - 
                              E^\((\(-S\) \((1 - x)\))\))\)/\((x \((1 - 
                                  x)\) \((1 - 
                                  E^\((\(-S\))\))\))\)\[IndentingNewLine]\ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \  + 
                      F[S]*\((1 - 
                              E^\((S \((1 - x)\))\))\)/\((x \((1 - 
                                  x)\) \((1 - 
                                  E^\((S)\))\))\))\)\[IndentingNewLine]\ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ *\((1 - x^n - \((1 - x)\)^n)\)*
                  gamma[\[Alpha], \[Beta], S], {x, 0, 1}, {S, 0.001, 
                  k}])\)\)\n\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \[IndentingNewLine]\[IndentingNewLine]\
\(EDs[l_, \[Rho]_, \[Lambda]_] := 
        l*\((1 - \[Rho])\)*\[Lambda]\)\n\n\(EDn[k_, 
          l_, \[Rho]_, \[Lambda]_, \[Alpha]_, \[Beta]_] \
:= \[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ l*\[Rho]*\
\[Lambda]*\ \((GammaRegularized[\[Beta], 0, 
                0.001*\[Alpha]] + \[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ NIntegrate[
                gamma[\[Alpha], \[Beta], 
                    S]*\((F[S]*P[\(-S\)] + F[\(-S\)]*P[S])\), {S, 0.001, 
                  k}])\)\)\)\)\)], "Input",
  PageWidth->Infinity]
}, Closed]],

Cell[CellGroupData[{

Cell["Analysis routines", "Section"],

Cell[BoxData[{
    \(Expected\[Theta]\[Lambda][
        data_] := \[IndentingNewLine]\ \ \ \ \ \ \ Module[{\[Theta], \
\[Lambda]}, \[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \[Theta] = 
          data\[LeftDoubleBracket]7\[RightDoubleBracket]/\((data\
\[LeftDoubleBracket]2\[RightDoubleBracket]*\((1 - 
                    data\[LeftDoubleBracket]3\[RightDoubleBracket])\)*
                Apply[Plus, 
                  Table[1/i, {i, 1, 
                      data\[LeftDoubleBracket]1\[RightDoubleBracket] - 
                        1}]])\); \[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \[Lambda] = 
          data\[LeftDoubleBracket]5\[RightDoubleBracket]/\((data\
\[LeftDoubleBracket]2\[RightDoubleBracket]*\((1 - 
                    data\[LeftDoubleBracket]3\[RightDoubleBracket])\))\); \
\[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ {\[Theta], \
\[Lambda]}]\n\), "\[IndentingNewLine]", 
    \(ExpectedData[n_, 
        l_, \[Rho]_, \[Theta]_, \[Lambda]_, \[Alpha]_, \[Beta]_] \
:= \[IndentingNewLine]\ \ \ \ \ \ Module[{eDn, eDs, ePn, 
          ePs}, \[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ eDn = EDn[
            l, \[Rho], \[Lambda], \[Alpha], \[Beta]]; \[IndentingNewLine]\ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ eDs = 
          EDs[l, \[Rho], \[Lambda]]; \[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ ePn = 
          EPn[l, n, \[Rho], \[Theta], \[Alpha], \[Beta]]; \[IndentingNewLine]\
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ ePs = 
          EPs[l, n, \[Rho], \[Theta]]; \[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ {eDs*ePn/\((eDn*ePs)\), eDn, eDs, ePn, 
          ePs}]\n\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(Likelihood[{n_, l_, \[Rho]_, Dn_, Ds_, Pn_, 
          Ps_}, {\[Theta]_, \[Lambda]_, \[Alpha]_, \[Beta]_}] := \n\t
      Module[{ePn, ePs, eDn, eDs, 
          like}, \[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ ePs = EPs[l, n, \[Rho], \[Theta]]; \n\t\t\ \ \ \ \ \ \ \ \ ePn = 
          EPn[l, n, \[Rho], \[Theta], \[Alpha], \[Beta]]; \[IndentingNewLine]\
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ eDs = 
          EDs[l, \[Rho], \[Lambda]]; \n\t\t\ \ \ \ \ \ \ \ \ eDn = 
          EDn[l, \[Rho], \[Lambda], \[Alpha], \[Beta]]; \n\t\t\ \ \ \ \ \ \ \ \
\ like = Poisson[ePn, Pn]*Poisson[eDn, Dn]*Poisson[ePs, Ps]*
            Poisson[eDs, 
              Ds]; \[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \  (*Print["\<L \>", 
            like, "\<   \[Alpha] \>", \[Alpha], "\<  \[Beta] \>", \[Beta], \
"\<  eDn \>", eDn, "\<  ePn \>", 
            ePn]; *) \n\t\t\ \ \ \ \ \ \ \ \ \ {like, {eDn, eDs, ePn, 
            ePs}}]\n\), "\n", 
    \(FindML[data_, meanSStart_, \[Beta]Start_] := \n\t
      Module[{ML, \[Alpha]ML, \[Beta]ML, meanSML, \[Theta], \[Lambda], 
          observed, expected, 
          GT}, \[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \[Theta] = 
          data\[LeftDoubleBracket]7\[RightDoubleBracket]/\((data\
\[LeftDoubleBracket]2\[RightDoubleBracket]*\((1 - 
                    data\[LeftDoubleBracket]3\[RightDoubleBracket])\)*
                Apply[Plus, 
                  Table[1/i, {i, 1, 
                      data\[LeftDoubleBracket]1\[RightDoubleBracket] - 
                        1}]])\); \n\t\t\ \ \ \ \ \ \ \ \[Lambda] = 
          data\[LeftDoubleBracket]5\[RightDoubleBracket]/\((data\
\[LeftDoubleBracket]2\[RightDoubleBracket]*\((1 - 
                    data\[LeftDoubleBracket]3\[RightDoubleBracket])\))\); \
\[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\[Alpha]Start = \[Beta]Start/
            meanSStart; \[IndentingNewLine]\t\ \ \ \ \ \ \ \ \ \ \ \ \ \ ML = 
          FindMinimum[\(-Log[\(Likelihood[
                    data, {\[Theta], \[Lambda], \[Alpha], \[Beta]}]\)\
\[LeftDoubleBracket]1\[RightDoubleBracket]]\), {\[Alpha], \[Alpha]Start, 
              1.1*\[Alpha]Start}, {\[Beta], \[Beta]Start, 
              1.1*\[Beta]Start}]; \n\t\t\ \ \ \ \ \ \ \ \ \[Alpha]ML = \
\[Alpha] /. 
            ML\[LeftDoubleBracket]2\[RightDoubleBracket]; \n\t\t\ \ \ \ \ \ \ \
\ \ \[Beta]ML = \[Beta] /. 
            ML\[LeftDoubleBracket]2\[RightDoubleBracket]; \[IndentingNewLine]\
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ meanSML = \
\[Beta]ML/\[Alpha]ML; \n\t\t\ \ \ \ \ \ \ \ \ observed = 
          Take[
            data, \(-4\)]; \n\t\t\ \ \ \ \ \ \ \ \ expected = \(Likelihood[
              data, {\[Theta], \[Lambda], \[Alpha]ML, \[Beta]ML}]\)\
\[LeftDoubleBracket]2\[RightDoubleBracket]; \n\t\t\ \ \ \ \ \ \ \ \ GT = 
          Gtest[observed, expected]; \n\t\t\ \ \ \ \ \ \ \ \ Print[
          TableForm[{Join[{"\<observed\>"}, observed], 
              Join[{"\<expected\>"}, expected], 
              Join[{"\<G value\>"}, 
                GT\[LeftDoubleBracket]1\[RightDoubleBracket]]}]]; \n\t\t\ \ \ \
\ \ \ \ \ \ Print["\<G test = \>", 
          GT\[LeftDoubleBracket]2\[RightDoubleBracket], "\<   ML values of \
meanS = \>", 
          meanSML, "\<  \[Beta]  = \>", \[Beta]ML, \ "\<   \[Theta] = \>", \
\[Theta], "\<   and \[Lambda] = \>", \[Lambda]]; \[IndentingNewLine]\ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ Print["\<Log Likelihood = \>", 
          Log[\(Likelihood[
                data, {\[Theta], \[Lambda], \[Alpha]ML, \[Beta]ML}]\)\
\[LeftDoubleBracket]1\[RightDoubleBracket]]]]\[IndentingNewLine]\
\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(FindMLlog[data_, meanSStart_, \[Beta]Start_] := \n\t
      Module[{ML, \[Alpha]ML, \[Beta]ML, meanSML, \[Theta], \[Lambda], 
          observed, expected, GT, log\[Alpha], 
          log\[Alpha]Start}, \[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \[Theta] = 
          data\[LeftDoubleBracket]7\[RightDoubleBracket]/\((data\
\[LeftDoubleBracket]2\[RightDoubleBracket]*\((1 - 
                    data\[LeftDoubleBracket]3\[RightDoubleBracket])\)*
                Apply[Plus, 
                  Table[1/i, {i, 1, 
                      data\[LeftDoubleBracket]1\[RightDoubleBracket] - 
                        1}]])\); \n\t\t\ \ \ \ \ \ \ \ \[Lambda] = 
          data\[LeftDoubleBracket]5\[RightDoubleBracket]/\((data\
\[LeftDoubleBracket]2\[RightDoubleBracket]*\((1 - 
                    data\[LeftDoubleBracket]3\[RightDoubleBracket])\))\); \
\[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
log\[Alpha]Start = 
          Log[\[Beta]Start/
              meanSStart]; \[IndentingNewLine]\t\ \ \ \ \ \ \ \ \ \ \ \ \ \ \
ML = FindMinimum[\(-Log[\(Likelihood[
                    data, {\[Theta], \[Lambda], 
                      E^log\[Alpha], \[Beta]}]\)\[LeftDoubleBracket]1\
\[RightDoubleBracket]]\), {log\[Alpha], log\[Alpha]Start, 
              1.1*log\[Alpha]Start}, {\[Beta], \[Beta]Start, 
              1.1*\[Beta]Start}]; \n\t\t\ \ \ \ \ \ \ \ \ \[Alpha]ML = 
          E^log\[Alpha] /. 
            ML\[LeftDoubleBracket]2\[RightDoubleBracket]; \n\t\t\ \ \ \ \ \ \ \
\ \ \[Beta]ML = \[Beta] /. 
            ML\[LeftDoubleBracket]2\[RightDoubleBracket]; \[IndentingNewLine]\
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ meanSML = \
\[Beta]ML/\[Alpha]ML; \n\t\t\ \ \ \ \ \ \ \ \ observed = 
          Take[data, \(-4\)]; \n\t\t\ \ \ \ \ \ \ \ \ expected = \(Likelihood[
              data, {\[Theta], \[Lambda], \[Alpha]ML, \[Beta]ML}]\)\
\[LeftDoubleBracket]2\[RightDoubleBracket]; \n\t\t\ \ \ \ \ \ \ \ \ GT = 
          Gtest[observed, expected]; \n\t\t\ \ \ \ \ \ \ \ \ Print[
          TableForm[{Join[{"\<observed\>"}, observed], 
              Join[{"\<expected\>"}, expected], 
              Join[{"\<G value\>"}, 
                GT\[LeftDoubleBracket]1\[RightDoubleBracket]]}]]; \n\t\t\ \ \ \
\ \ \ \ \ \ Print["\<G test = \>", 
          GT\[LeftDoubleBracket]2\[RightDoubleBracket], "\<   ML values of \
meanS = \>", 
          meanSML, "\<  \[Beta]  = \>", \[Beta]ML, \ "\<   \[Theta] = \>", \
\[Theta], "\<   and \[Lambda] = \>", \[Lambda]]; \[IndentingNewLine]\ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ Print["\<Log Likelihood = \>", 
          Log[\(Likelihood[
                data, {\[Theta], \[Lambda], \[Alpha]ML, \[Beta]ML}]\)\
\[LeftDoubleBracket]1\[RightDoubleBracket]]]]\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(CI\[Beta][data_, meanSStart_, \[Beta]_] := \n\t
      Module[{ML, meanSML, \[Beta]ML, \[Theta], \[Lambda], observed, 
          expected, GT, log\[Alpha], 
          log\[Alpha]Start}, \[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \[Theta] = 
          data\[LeftDoubleBracket]7\[RightDoubleBracket]/\((data\
\[LeftDoubleBracket]2\[RightDoubleBracket]*\((1 - 
                    data\[LeftDoubleBracket]3\[RightDoubleBracket])\)*
                Apply[Plus, 
                  Table[1/i, {i, 1, 
                      data\[LeftDoubleBracket]1\[RightDoubleBracket] - 
                        1}]])\); \n\t\t\ \ \ \ \ \ \ \ \[Lambda] = 
          
          data\[LeftDoubleBracket]5\[RightDoubleBracket]/\((data\
\[LeftDoubleBracket]2\[RightDoubleBracket]*\((1 - 
                    data\[LeftDoubleBracket]3\[RightDoubleBracket])\))\); \
\[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ ML = 
          FindMinimum[\(-Log[\(Likelihood[
                    data, {\[Theta], \[Lambda], \[Beta]/
                        meanS, \[Beta]}]\)\[LeftDoubleBracket]1\
\[RightDoubleBracket]]\), {meanS, meanSStart, 
              1.1*meanSStart}]; \n\t\t\ \ \ \ \ \ \ \ \ meanSML = 
          meanS /. 
            ML\[LeftDoubleBracket]2\[RightDoubleBracket]; \n\t\t\ \ \ \ \ \ \ \
\ \ observed = 
          Take[data, \(-4\)]; \n\t\t\ \ \ \ \ \ \ \ \ expected = \(Likelihood[
              data, {\[Theta], \[Lambda], \[Beta]/
                  meanSML, \[Beta]}]\)\[LeftDoubleBracket]2\
\[RightDoubleBracket]; \n\t\t\ \ \ \ \ \ \ \ \ GT = 
          Gtest[observed, expected]; \n\t\t\ \ \ \ \ \ \ \ \ Print[
          TableForm[{Join[{"\<observed\>"}, observed], 
              Join[{"\<expected\>"}, expected], 
              Join[{"\<G value\>"}, 
                GT\[LeftDoubleBracket]1\[RightDoubleBracket]]}]]; \n\t\t\ \ \ \
\ \ \ \ \ \ Print["\<G test = \>", 
          GT\[LeftDoubleBracket]2\[RightDoubleBracket], "\<   ML values of \
meanS = \>", 
          meanSML, \ "\<   \[Theta] = \>", \[Theta], "\<   and \[Lambda] = \
\>", \[Lambda]]; \[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ Print["\<Log Likelihood = \>", 
          Log[\(Likelihood[
                data, {\[Theta], \[Lambda], \[Beta]/
                    meanSML, \[Beta]}]\)\[LeftDoubleBracket]1\
\[RightDoubleBracket]]]]\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(CImeanS[data_, meanS_, \[Beta]Start_] := \n\t
      Module[{ML, \[Beta]ML, \[Theta], \[Lambda], observed, expected, 
          GT}, \[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \[Theta] = 
          data\[LeftDoubleBracket]7\[RightDoubleBracket]/\((data\
\[LeftDoubleBracket]2\[RightDoubleBracket]*\((1 - 
                    data\[LeftDoubleBracket]3\[RightDoubleBracket])\)*
                Apply[Plus, 
                  Table[1/i, {i, 1, 
                      data\[LeftDoubleBracket]1\[RightDoubleBracket] - 
                        1}]])\); \n\t\t\ \ \ \ \ \ \ \ \[Lambda] = 
          
          data\[LeftDoubleBracket]5\[RightDoubleBracket]/\((data\
\[LeftDoubleBracket]2\[RightDoubleBracket]*\((1 - 
                    data\[LeftDoubleBracket]3\[RightDoubleBracket])\))\); \
\[IndentingNewLine]\t\ \ \ \ \ \ \ \ \ \ \ \ \ \ ML = 
          FindMinimum[\(-Log[\(Likelihood[
                    data, {\[Theta], \[Lambda], \[Beta]/
                        meanS, \[Beta]}]\)\[LeftDoubleBracket]1\
\[RightDoubleBracket]]\), {\[Beta], \[Beta]Start, 
              1.1*\[Beta]Start}]; \n\t\t\ \ \ \ \ \ \ \ \ \[Beta]ML = \[Beta] \
/. ML\[LeftDoubleBracket]2\[RightDoubleBracket]; \n\t\t\ \ \ \ \ \ \ \ \ \
observed = 
          Take[data, \(-4\)]; \n\t\t\ \ \ \ \ \ \ \ \ expected = \(Likelihood[
              data, {\[Theta], \[Lambda], \[Beta]ML/
                  meanS, \[Beta]ML}]\)\[LeftDoubleBracket]2\
\[RightDoubleBracket]; \n\t\t\ \ \ \ \ \ \ \ \ GT = 
          Gtest[observed, expected]; \n\t\t\ \ \ \ \ \ \ \ \ Print[
          TableForm[{Join[{"\<observed\>"}, observed], 
              Join[{"\<expected\>"}, expected], 
              Join[{"\<G value\>"}, 
                GT\[LeftDoubleBracket]1\[RightDoubleBracket]]}]]; \n\t\t\ \ \ \
\ \ \ \ \ \ Print["\<G test = \>", 
          GT\[LeftDoubleBracket]2\[RightDoubleBracket], "\<   ML values of \
\[Beta]  = \>", \[Beta]ML, \ "\<   \[Theta] = \>", \[Theta], "\<   and \
\[Lambda] = \>", \[Lambda]]; \[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ Print["\<Log Likelihood = \>", 
          Log[\(Likelihood[
                data, {\[Theta], \[Lambda], \[Beta]ML/
                    meanS, \[Beta]ML}]\)\[LeftDoubleBracket]1\
\[RightDoubleBracket]]]]\[IndentingNewLine]\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(ManualML[data_, meanS_, \[Beta]_] := \n\t
      Module[{ML, \[Theta], \[Lambda], observed, expected, 
          GT, \[Alpha]}, \[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \[Alpha] = \[Beta]/
            meanS; \[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \[Theta] = 
          data\[LeftDoubleBracket]7\[RightDoubleBracket]/\((data\
\[LeftDoubleBracket]2\[RightDoubleBracket]*\((1 - 
                    data\[LeftDoubleBracket]3\[RightDoubleBracket])\)*
                Apply[Plus, 
                  Table[1/i, {i, 1, 
                      data\[LeftDoubleBracket]1\[RightDoubleBracket] - 
                        1}]])\); \n\t\t\ \ \ \ \ \ \ \ \[Lambda] = 
          data\[LeftDoubleBracket]5\[RightDoubleBracket]/\((data\
\[LeftDoubleBracket]2\[RightDoubleBracket]*\((1 - 
                    data\[LeftDoubleBracket]3\[RightDoubleBracket])\))\); \
\[IndentingNewLine]\t\t\ \ \ \ observed = 
          Take[data, \(-4\)]; \n\t\t\ \ \ \ \ \ \ \ \ expected = \(Likelihood[
              data, {\[Theta], \[Lambda], \[Alpha], \[Beta]}]\)\
\[LeftDoubleBracket]2\[RightDoubleBracket]; \n\t\t\ \ \ \ \ \ \ \ \ GT = 
          Gtest[observed, expected]; \n\t\t\ \ \ \ \ \ \ \ \ Print[
          TableForm[{Join[{"\<observed\>"}, observed], 
              Join[{"\<expected\>"}, expected], 
              Join[{"\<G value\>"}, 
                GT\[LeftDoubleBracket]1\[RightDoubleBracket]]}]]; \n\t\t\ \ \ \
\ \ \ \ \ \ Print["\<G test = \>", 
          GT\[LeftDoubleBracket]2\[RightDoubleBracket], "\<   Values of \
\[Alpha] = \>", \[Alpha], "\<  \[Beta]  = \>", \[Beta], \ "\<   \[Theta] = \
\>", \[Theta], "\<   and \[Lambda] = \>", \[Lambda]]; \[IndentingNewLine]\ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ Print["\<Log Likelihood = \>", 
          Log[\(Likelihood[
                data, {\[Theta], \[Lambda], \[Alpha], \[Beta]}]\)\
\[LeftDoubleBracket]1\[RightDoubleBracket]]]]\), "\n", 
    \(\)}], "Input",
  PageWidth->Infinity,
  CellChangeTimes -> {{3.5286245364792023`*^9, 3.528624536628955*^9}, \
{3.5286248577296667`*^9, 3.528624882765361*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Example data and analysis
The example data is the Human mtDNA dataset from Piganeau and EW. The answers \
differ very slightly from what they obtained because the method implemented \
here uses a better method of integrating over the gamma distribution, due to \
John Welch and David Waxman. You should get \[Alpha]=0.00024558 and \
\[Beta]=0.386659.\
\>", "Section"],

Cell[BoxData[
    \(\(\(ExampleData = {53, 11259, 0.68, 186, 1765, 91, 
        320}; \)\(\n\)\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(FindML[ExampleData, 1000, 0.38]\)], "Input",
  CellChangeTimes -> {{3.528624901661561*^9, 3.5286249037377167`*^9}}],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"observed\"\>", "186", "1765", "91", "320"},
          {"\<\"expected\"\>", "185.9999723467706`", "1764.9999999999998`", 
            "90.99997124576038`", "320.`"},
          {"\<\"G value\"\>", "0.00005530646295345591`", 
            "7.838174553853604`*^-13", "0.00005750848834545944`", "0.`"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ BoxForm`e$]]]], "Print"],

Cell[BoxData[
    InterpretationBox[\("G test = "\[InvisibleSpace]0.00011281495208273281`\
\[InvisibleSpace]"   ML values of meanS = \
"\[InvisibleSpace]1574.4759723393504`\[InvisibleSpace]"  \[Beta]  = "\
\[InvisibleSpace]0.3866593939603051`\[InvisibleSpace]"   \[Theta] = "\
\[InvisibleSpace]0.019571832178386372`\[InvisibleSpace]"   and \[Lambda] = "\
\[InvisibleSpace]0.4898858690825118`\),
      SequenceForm[ 
      "G test = ", 0.00011281495208273281, "   ML values of meanS = ", 
        1574.4759723393504, "  \[Beta]  = ", 0.38665939396030508, 
        "   \[Theta] = ", 0.019571832178386372, "   and \[Lambda] = ", 
        0.4898858690825118],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Log Likelihood = \
"\[InvisibleSpace]\(-15.167842111927339`\)\),
      SequenceForm[ "Log Likelihood = ", -15.167842111927339],
      Editable->False]], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(FindMLlog\[Alpha][ExampleData, 1000, 0.5]\)], "Input",
  CellChangeTimes -> {{3.528624917510727*^9, 3.528624919569652*^9}}],

Cell[BoxData[
    \(FindMLlog\[Alpha][{53, 11259, 0.68`, 186, 1765, 91, 320}, 1000, 
      0.5`]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(data = {9, 1140, 0.70, 14, 142, 5, 7}\)], "Input",
  FormatType->InputForm,
  CellChangeTimes -> {{3.528624572942184*^9, 3.528624611303647*^9}, \
{3.528624714846573*^9, 3.52862473143581*^9}}],

Cell[BoxData[
    \({9, 1140, 0.7`, 14, 142, 5, 7}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(FindML[data, 10, 1.1]\)], "Input",
  FormatType->InputForm,
  CellChangeTimes -> {{3.5286247375030327`*^9, 3.528624760930386*^9}, \
{3.528624791251668*^9, 3.528624817144683*^9}, {3.52862493393443*^9, \
3.528624974548833*^9}}],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"observed\"\>", "14", "142", "5", "7"},
          {"\<\"expected\"\>", "13.999999441941062`", "142.`", 
            "4.999996143270274`", "7.000000000000001`"},
          {"\<\"G value\"\>", "1.1161178958424262`*^-6", "0.`", 
            "7.7134624270836`*^-6", "0.`"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ BoxForm`e$]]]], "Print"],

Cell[BoxData[
    InterpretationBox[\("G test = "\[InvisibleSpace]8.829580322926025`*^-6\
\[InvisibleSpace]"   ML values of meanS = \
"\[InvisibleSpace]12.482048516086342`\[InvisibleSpace]"  \[Beta]  = "\
\[InvisibleSpace]1.9784067398026517`\[InvisibleSpace]"   \[Theta] = "\
\[InvisibleSpace]0.007530872735935326`\[InvisibleSpace]"   and \[Lambda] = "\
\[InvisibleSpace]0.415204678362573`\),
      SequenceForm[ 
      "G test = ", 8.8295803229260252*^-06, "   ML values of meanS = ", 
        12.482048516086342, "  \[Beta]  = ", 1.9784067398026517, 
        "   \[Theta] = ", 0.0075308727359353258, "   and \[Lambda] = ", 
        0.41520467836257302],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Log Likelihood = \
"\[InvisibleSpace]\(-9.2859499819116`\)\),
      SequenceForm[ "Log Likelihood = ", -9.2859499819115996],
      Editable->False]], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ManualML[data,12,1.9]", "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"observed\"\>", "14", "142", "5", "7"},
          {"\<\"expected\"\>", "15.940102464460853`", "142.`", 
            "5.18928862730383`", "7.000000000000001`"},
          {"\<\"G value\"\>", \(-3.6338616120927947`\), 
            "0.`", \(-0.3715870931919956`\), "0.`"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ BoxForm`e$]]]], "Print"],

Cell[BoxData[
    InterpretationBox[\("G test = "\[InvisibleSpace]\(-4.00544870528479`\)\
\[InvisibleSpace]"   Values of \[Alpha] = \
"\[InvisibleSpace]0.15833333333333333`\[InvisibleSpace]"  \[Beta]  = "\
\[InvisibleSpace]1.9`\[InvisibleSpace]"   \[Theta] = \
"\[InvisibleSpace]0.007530872735935326`\[InvisibleSpace]"   and \[Lambda] = "\
\[InvisibleSpace]0.415204678362573`\),
      SequenceForm[ 
      "G test = ", -4.00544870528479, "   Values of \[Alpha] = ", 
        0.15833333333333333, "  \[Beta]  = ", 1.8999999999999999, 
        "   \[Theta] = ", 0.0075308727359353258, "   and \[Lambda] = ", 
        0.41520467836257302],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Log Likelihood = \
"\[InvisibleSpace]\(-9.41261672103239`\)\),
      SequenceForm[ "Log Likelihood = ", -9.4126167210323892],
      Editable->False]], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ManualML[data,1000,1.9]", "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"observed\"\>", "14", "142", "5", "7"},
          {"\<\"expected\"\>", "0.0051760117867200705`", "142.`", 
            "0.11047447965213088`", "7.000000000000001`"},
          {"\<\"G value\"\>", "221.27777767800205`", "0.`", 
            "38.12408650506649`", "0.`"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ BoxForm`e$]]]], "Print"],

Cell[BoxData[
    InterpretationBox[\("G test = "\[InvisibleSpace]259.40186418306854`\
\[InvisibleSpace]"   Values of \[Alpha] = "\[InvisibleSpace]0.0019`\
\[InvisibleSpace]"  \[Beta]  = "\[InvisibleSpace]1.9`\[InvisibleSpace]"   \
\[Theta] = "\[InvisibleSpace]0.007530872735935326`\[InvisibleSpace]"   and \
\[Lambda] = "\[InvisibleSpace]0.415204678362573`\),
      SequenceForm[ 
      "G test = ", 259.40186418306854, "   Values of \[Alpha] = ", 0.0019, 
        "  \[Beta]  = ", 1.8999999999999999, "   \[Theta] = ", 
        0.0075308727359353258, "   and \[Lambda] = ", 0.41520467836257302],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Log Likelihood = \
"\[InvisibleSpace]\(-120.10253256488322`\)\),
      SequenceForm[ "Log Likelihood = ", -120.10253256488322],
      Editable->False]], "Print"]
}, Open  ]],

Cell["\<\
ExpectedData1[n_,l_,\[Rho]_,\[Theta]_,\[Lambda]_,meanS_,\[Beta]_]:=
        Module[{eDn,eDs,ePn,ePs,\[Alpha]},
                          \[Alpha]=\[Beta]/meanS;
                          eDn=EDn[l,\[Rho],\[Lambda],\[Alpha],\[Beta]];
                          eDs=EDs[l,\[Rho],\[Lambda]];
                          ePn=EPn[l,n,\[Rho],\[Theta],\[Alpha],\[Beta]];
                          ePs=EPs[l,n,\[Rho],\[Theta]];
                          {eDs*ePn/(eDn*ePs),eDn,eDs,ePn,ePs}]
\
\>", "Input"],

Cell[CellGroupData[{

Cell["ExpectedData1[9,1140,0.70,0.0075,0.41,1.25,1.9]", "Input"],

Cell[BoxData[
    \({1.4951570270073777`, 181.06252833360236`, 140.22000000000003`, 
      13.459205337641796`, 6.971303571428572`}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ExpectedData1[9,1140,0.70,0.0075,0.41,12.5,1.9]", "Input"],

Cell[BoxData[
    \({6.8508251774774545`, 14.769065205674728`, 140.22000000000003`, 
      5.030369943846641`, 6.971303571428572`}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ExpectedData1[9,1140,0.70,0.0075,0.41,125,1.9]", "Input"],

Cell[BoxData[
    \({61.70722476483073`, 0.2568090263237949`, 140.22000000000003`, 
      0.7878623210245297`, 6.971303571428572`}\)], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.2 for Macintosh",
ScreenRectangle->{{0, 1280}, {0, 733}},
WindowSize->{1192, 979},
WindowMargins->{{Automatic, 21}, {Automatic, 0}},
DockedCells -> FEPrivate`FrontEndResource[ "FEExpressions", \
"CompatibilityToolbar"],
StyleDefinitions -> "Default.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 95, 3, 156, "Title"],
Cell[1874, 58, 3281, 47, 848, "Section"],

Cell[CellGroupData[{
Cell[5180, 109, 45, 0, 56, "Section"],
Cell[5228, 111, 256, 5, 59, "Input"],
Cell[5487, 118, 644, 13, 187, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6168, 136, 54, 0, 56, "Section"],
Cell[6225, 138, 1253, 24, 267, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7515, 167, 61, 0, 56, "Section"],
Cell[7579, 169, 2464, 41, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[10080, 215, 36, 0, 36, "Section"],
Cell[10119, 217, 15229, 268, 1563, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[25385, 490, 377, 7, 128, "Section"],
Cell[25765, 499, 109, 2, 43, "Input"],

Cell[CellGroupData[{
Cell[25899, 505, 135, 2, 27, "Input"],
Cell[26037, 509, 551, 13, 55, "Print"],
Cell[26591, 524, 689, 12, 23, "Print"],
Cell[27283, 538, 200, 4, 23, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[27520, 547, 143, 2, 27, "Input"],
Cell[27666, 551, 110, 2, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[27813, 558, 211, 4, 27, "Input"],
Cell[28027, 564, 64, 1, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[28128, 570, 245, 5, 27, "Input"],
Cell[28376, 577, 523, 13, 55, "Print"],
Cell[28902, 592, 689, 12, 25, "Print"],
Cell[29594, 606, 197, 4, 23, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[29828, 615, 38, 0, 27, "Input"],
Cell[29869, 617, 523, 13, 53, "Print"],
Cell[30395, 632, 670, 12, 23, "Print"],
Cell[31068, 646, 198, 4, 23, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[31303, 655, 40, 0, 27, "Input"],
Cell[31346, 657, 522, 13, 53, "Print"],
Cell[31871, 672, 631, 10, 23, "Print"],
Cell[32505, 684, 200, 4, 23, "Print"]
}, Open  ]],
Cell[32720, 691, 505, 10, 147, "Input"],

Cell[CellGroupData[{
Cell[33250, 705, 64, 0, 27, "Input"],
Cell[33317, 707, 145, 2, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[33499, 714, 64, 0, 27, "Input"],
Cell[33566, 716, 144, 2, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[33747, 723, 63, 0, 27, "Input"],
Cell[33813, 725, 144, 2, 27, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

